@@ -1,15 +1,13 @@
 #########
 # Author:        Andy Jenkinson
 # Created:       2008-02-20
-# Last Modified: $Date: 2010-11-02 11:57:52 +0000 (Tue, 02 Nov 2010) $ $Author: zerojinx $
-# Id:            $Id: http.pm 688 2010-11-02 11:57:52Z zerojinx $
+# Last Modified: $Date: 2008-03-12 14:50:11 +0000 (Wed, 12 Mar 2008) $ $Author: andyjenkinson $
+# Id:            $Id: http.pm 453 2008-03-12 14:50:11Z andyjenkinson $
 # Source:        $Source$
-# $HeadURL: https://proserver.svn.sourceforge.net/svnroot/proserver/trunk/lib/Bio/Das/ProServer/Authenticator/http.pm $
+# $HeadURL: https://zerojinx@proserver.svn.sf.net/svnroot/proserver/trunk/lib/Bio/Das/ProServer/Authenticator/http.pm $
 #
 # Authenticator implementation using a remote authority to control access.
 #
-## no critic (ValuesAndExpressions::ProhibitMagicNumbers)
-#
 package Bio::Das::ProServer::Authenticator::http;
 
 use strict;
@@ -17,84 +15,61 @@ use warnings;
 use Carp;
 use LWP::UserAgent;
 use Cache::FileCache;
-use English qw(-no_match_vars);
 use Bio::Das::ProServer::Config;
 use base qw(Bio::Das::ProServer::Authenticator);
-use English qw(-no_match_vars);
 
-our $VERSION = do { my ($v) = (q$LastChangedRevision: 688 $ =~ /\d+/mxsg); $v; };
+our $VERSION = do { my ($v) = (q$LastChangedRevision: 453 $ =~ /\d+/mxg); $v; };
 
 sub parse_token {
   my ($self, $params) = @_;
   my $token;
-
+  # Look in a cookie
   if (defined $self->{'config'}{'authcookie'}) {
-    #########
-    # Look in a cookie
-    #
     my $k = $self->{'config'}{'authcookie'};
-    ($token) = $params->{'request'}->header('cookie') =~ m/$k=([^;]*)/mxs;
+    ($token) = $params->{'request'}->header('cookie') =~ m/$k=([^;]*)/mx;
     $self->{'debug'} && carp "Authenticator parsed token in cookie: $token";
-
-  } elsif (defined $self->{'config'}{'authparam'}) {
-    #########
-    # Look in a cgi param
-    #
+  }
+  # Look in a cgi param
+  elsif (defined $self->{'config'}{'authparam'}) {
     $token = $params->{'cgi'}->param($self->{'config'}{'authparam'});
     $self->{'debug'} && carp "Authenticator parsed token in param: $token";
-
-  } else {
-    #########
-    # Look in a specified header (default to 'Authorization')
-    #
+  }
+  # Look in a specified header (default to 'Authorization')
+  else {
     $token = $params->{'request'}->header($self->{'config'}{'authheader'}||'Authorization');
     $self->{'debug'} && carp "Authenticator parsed token in header: $token";
   }
-
   return $token;
 }
 
 sub authenticate {
   my ($self, $params) = @_;
-
+  
   my $token = $self->parse_token($params);
-  if(!$token) {
-    return $self->deny($params);
-  }
-
+  $token || return $self->deny($params);
   my $auth_response = $self->_cache()->get($token);
-
   if (defined $auth_response) {
     $self->{'debug'} && carp q(Authenticator found result in cache);
-
   } else {
     my $url = $self->{'config'}{'authurl'};
-    $url    =~ s/%token/$token/mxsg;
+    $url =~ s/%token/$token/mxg;
     $self->{'debug'} && carp qq(Authenticator issuing remote authentication request to $url);
     $auth_response = $self->_agent()->get($url);
-
     if ($auth_response->code() != 500) {
-      eval {
-        delete $auth_response->{'handlers'};
-        $self->_cache()->set($token, $auth_response);
-        1;
-      } or do {
-        carp qq[Failed to cache $token response: $EVAL_ERROR];
-      };
+      $self->_cache()->set($token, $auth_response);
     }
   }
-
+  
   if ($auth_response->code() == 200) {
     return $self->allow($params);
+  } else {
+    $self->{'debug'} && carp q(Authenticator denied request);
+    return $auth_response;
   }
-
-  $self->{'debug'} && carp q(Authenticator denied request);
-  return $auth_response;
 }
 
 sub _cache {
   my $self = shift;
-
   if (!defined $self->{'_cache'}) {
     $self->{'_cache'} = Cache::FileCache->new({
       'namespace'           => sprintf('%s_auth_cache', $self->{'dsn'}||'unknown'),
@@ -102,16 +77,13 @@ sub _cache {
       'auto_purge_interval' => 10*60, # 10 minutes
       'auto_purge_on_set'   => 1,
     });
-
     $self->{'_cache'}->clear();
   }
-
   return $self->{'_cache'};
 }
 
 sub _agent {
   my $self = shift;
-
   if (!defined $self->{'_agent'}) {
     $self->{'_agent'} = LWP::UserAgent->new(
       env_proxy  => 1,
@@ -120,7 +92,6 @@ sub _agent {
       agent      => Bio::Das::ProServer::Config::server_version(),
     );
   }
-
   return $self->{'_agent'};
 }
 
@@ -134,7 +105,7 @@ requests to a remote authority
 
 =head1 VERSION
 
-$LastChangedRevision: 688 $
+$LastChangedRevision: 453 $
 
 =head1 SYNOPSIS
 
@@ -242,11 +213,11 @@ An HTTP proxy may be specified in the shell environment.
 
 =over
 
-=item L<Carp|Carp>
+=item L<Carp>
 
-=item L<Bio::Das::ProServer::Authenticator|Bio::Das::ProServer::Authenticator>
+=item L<Bio::Das::ProServer::Authenticator>
 
-=item L<LWP::UserAgent|LWP::UserAgent>
+=item L<LWP::UserAgent>
 
 =back
 
@@ -269,4 +240,4 @@ Andy Jenkinson <andy.jenkinson@ebi.ac.uk>
 
 Copyright (c) 2008 EMBL-EBI
 
-=cut
+=cut
\ No newline at end of file
