@@ -1,10 +1,10 @@
 #########
 # Author:        Andy Jenkinson
 # Created:       2008-02-01
-# Last Modified: $Date: 2010-11-02 11:57:52 +0000 (Tue, 02 Nov 2010) $ $Author: zerojinx $
-# Id:            $Id: sif.pm 688 2010-11-02 11:57:52Z zerojinx $
+# Last Modified: $Date: 2008-03-12 14:50:11 +0000 (Wed, 12 Mar 2008) $ $Author: andyjenkinson $
+# Id:            $Id: sif.pm 453 2008-03-12 14:50:11Z andyjenkinson $
 # Source:        $Source$
-# $HeadURL: https://proserver.svn.sourceforge.net/svnroot/proserver/trunk/lib/Bio/Das/ProServer/SourceAdaptor/sif.pm $
+# $HeadURL: https://zerojinx@proserver.svn.sf.net/svnroot/proserver/trunk/lib/Bio/Das/ProServer/SourceAdaptor/sif.pm $
 #
 # SourceAdaptor implementation for Simple Interaction Format files.
 #
@@ -14,7 +14,7 @@ use warnings;
 use Carp;
 use base qw(Bio::Das::ProServer::SourceAdaptor);
 
-our $VERSION = do { my ($v) = (q$LastChangedRevision: 688 $ =~ /\d+/mxsg); $v; };
+our $VERSION = do { my ($v) = (q$LastChangedRevision: 453 $ =~ /\d+/mxg); $v; };
 
 sub capabilities {
   return { 'interaction' => '1.0' };
@@ -22,14 +22,14 @@ sub capabilities {
 
 sub build_interaction {
   my ($self, $args) = @_;
-  my $struct = $self->transport->query($args);
+  my $struct = $self->transport->query($args->{'interactors'});
 
   my $coord_sys = $self->coordinates_full()->[0]->{description};
   my @params = qw(dbSource dbSourceCvId dbVersion);
 
   my @interactions = @{ $struct->{'interactions'} };
   my @interactors  = @{ $struct->{'interactors'}  };
-
+  
   $self->{debug} && carp sprintf q(Found %d interactions with %d interactors),
                     scalar @interactions,
                     scalar @interactors;
@@ -56,7 +56,7 @@ Bio::Das::ProServer::SourceAdaptor::sif
 
 =head1 VERSION
 
-$LastChangedRevision: 688 $
+$LastChangedRevision: 453 $
 
 =head1 SYNOPSIS
 
@@ -69,7 +69,7 @@ $LastChangedRevision: 688 $
 =head1 DESCRIPTION
 
 Serves up interaction DAS responses from 'Simple Interaction Format' (SIF) files.
-See L<http://www.cytoscape.org/cgi-bin/moin.cgi/Cytoscape_User_Manual/Network_Formats|http://www.cytoscape.org/cgi-bin/moin.cgi/Cytoscape_User_Manual/Network_Formats>
+See L<http://www.cytoscape.org/cgi-bin/moin.cgi/Cytoscape_User_Manual/Network_Formats>
 http://www.cytoscape.org/cgi-bin/moin.cgi/Cytoscape_User_Manual/Network_Formats
 for details of the file format.
 
@@ -111,11 +111,11 @@ This adaptor supports the 'interaction' command only.
 
 =over
 
-=item L<Bio::Das::ProServer::SourceAdaptor::Transport::sif|Bio::Das::ProServer::SourceAdaptor::Transport::sif>
+=item L<Bio::Das::ProServer::SourceAdaptor::Transport::sif>
 
-=item L<http://www.cytoscape.org/cgi-bin/moin.cgi/Cytoscape_User_Manual/Network_Formats|http://www.cytoscape.org/cgi-bin/moin.cgi/Cytoscape_User_Manual/Network_Formats> Cytoscape - SIF
+=item L<http://www.cytoscape.org/cgi-bin/moin.cgi/Cytoscape_User_Manual/Network_Formats> Cytoscape - SIF
 
-=item L<http://www.cytoscape.org/cgi-bin/moin.cgi/Cytoscape_User_Manual/Attributes|http://www.cytoscape.org/cgi-bin/moin.cgi/Cytoscape_User_Manual/Attributes> Cytoscape - Attributes
+=item L<http://www.cytoscape.org/cgi-bin/moin.cgi/Cytoscape_User_Manual/Attributes> Cytoscape - Attributes
 
 =back
 
@@ -123,11 +123,11 @@ This adaptor supports the 'interaction' command only.
 
 =over
 
-=item L<Carp|Carp> 
+=item L<Carp> 
 
-=item L<Bio::Das::ProServer::SourceAdaptor|Bio::Das::ProServer::SourceAdaptor> 
+=item L<Bio::Das::ProServer::SourceAdaptor> 
 
-=item L<Bio::Das::ProServer::SourceAdaptor::Transport::sif|Bio::Das::ProServer::SourceAdaptor::Transport::sif>
+=item L<Bio::Das::ProServer::SourceAdaptor::Transport::sif>
 
 =back
 
