@@ -2,19 +2,16 @@
 # Author:        jws
 # Maintainer:    jws
 # Created:       2005-04-20
-# Last Modified: $Date: 2010-11-02 11:37:11 +0000 (Tue, 02 Nov 2010) $
-# $Id: styletest.pm 687 2010-11-02 11:37:11Z zerojinx $
-# $HeadURL: https://proserver.svn.sourceforge.net/svnroot/proserver/trunk/lib/Bio/Das/ProServer/SourceAdaptor/styletest.pm $
-#
-# lots of magic numbers in this package:
-## no critic (ValuesAndExpressions::ProhibitMagicNumbers)
+# Last Modified: $Date: 2008-03-12 14:50:11 +0000 (Wed, 12 Mar 2008) $
+# $Id: styletest.pm 453 2008-03-12 14:50:11Z andyjenkinson $
+# $HeadURL: https://zerojinx@proserver.svn.sf.net/svnroot/proserver/trunk/lib/Bio/Das/ProServer/SourceAdaptor/styletest.pm $
 #
 package Bio::Das::ProServer::SourceAdaptor::styletest;
 use strict;
 use warnings;
 use base qw(Bio::Das::ProServer::SourceAdaptor);
 
-our $VERSION  = do { my ($v) = (q$Revision: 687 $ =~ /\d+/mxsg); $v; };
+our $VERSION  = do { my @r = (q$Revision: 453 $ =~ /\d+/mxg); sprintf '%d.'.'%03d' x $#r, @r };
 
 sub capabilities {
   return {
@@ -50,12 +47,12 @@ sub build_features {
   #
   my @types;
 
-  for my $ss (split /\n/mxs, $stylesheet) {
-    if($ss !~ /<\s*TYPE/mxsi) {
+  for my $ss (split /\n/mx, $stylesheet) {
+    if($ss !~ /<\s*TYPE/mix) {
       next;
     }
 
-    my ($trap) = $ss =~ /id\s*=\s*["']{1}([^"']*)["']{1}/mxsi;
+    my ($trap) = $ss =~ /id\s*=\s*["']{1}([^"']*)["']{1}/mix;
     if($trap) {
       push @types, $1;
     }
@@ -66,7 +63,7 @@ sub build_features {
     # workaround for annoying Bio::Das method forcing type to method:type
     #
     my $method = $type;
-    $method    =~ s/:.*//mxs; # throw away everything after :
+    $method    =~ s/:.*//mx; # throw away everything after :
 
     #########
     # create a number of features for each type, on each strand:
@@ -189,7 +186,7 @@ Bio::Das::ProServer::SourceAdaptor::styletest
 
 =head1 VERSION
 
-$LastChangedRevision: 687 $
+$LastChangedRevision: 453 $
 
 =head1 SYNOPSIS
 
