@@ -2,10 +2,10 @@
 # Author:        rmp
 # Maintainer:    rmp
 # Created:       2003-12-12
-# Last Modified: $Date: 2007/02/28 12:23:44 $ $Author: rmp $
-# Id:            $Id: dbi.pm,v 2.52 2007/02/28 12:23:44 rmp Exp $
-# Source:        $Source: /cvsroot/Bio-Das-ProServer/Bio-Das-ProServer/lib/Bio/Das/ProServer/SourceHydra/dbi.pm,v $
-# $HeadURL$
+# Last Modified: $Date: 2008-03-12 14:50:11 +0000 (Wed, 12 Mar 2008) $ $Author: andyjenkinson $
+# Id:            $Id: dbi.pm 453 2008-03-12 14:50:11Z andyjenkinson $
+# Source:        $Source: /nfs/team117/rmp/tmp/Bio-Das-ProServer/Bio-Das-ProServer/lib/Bio/Das/ProServer/SourceHydra/dbi.pm,v $
+# $HeadURL: https://zerojinx@proserver.svn.sf.net/svnroot/proserver/trunk/lib/Bio/Das/ProServer/SourceHydra/dbi.pm $
 #
 # DBI-driven sourceadaptor broker
 #
@@ -16,7 +16,7 @@ use base qw(Bio::Das::ProServer::SourceHydra);
 use English qw(-no_match_vars);
 use Carp;
 
-our $VERSION       = do { my @r = (q$Revision: 2.52 $ =~ /\d+/mxg); sprintf '%d.'.'%03d' x $#r, @r };
+our $VERSION       = do { my @r = (q$Revision: 453 $ =~ /\d+/mxg); sprintf '%d.'.'%03d' x $#r, @r };
 our $CACHE_TIMEOUT = 30;
 
 #########
@@ -32,7 +32,7 @@ sub sources {
   # flush the table cache *at most* once every $CACHE_TIMEOUT
   # This may need signal triggering to have immediate support
   #
-  if($now > $self->{'_tablecache_timestamp'}+$CACHE_TIMEOUT) {
+  if($now > ($self->{'_tablecache_timestamp'} || 0)+$CACHE_TIMEOUT) {
     $self->{'debug'} and carp qq(Flushing table-cache for $dsn);
     delete $self->{'_tables'};
     $self->{'_tablecache_timestamp'} = $now;
@@ -51,8 +51,7 @@ sub sources {
       $sth->execute();
 
       $self->{'_tables'} = [map {
-	my ($remainder) = $_->[0] =~ /^.{$l}(.*)$/mx;
-	$dsn.$remainder;
+	$dsn.($_->[0] =~ /^.{$l}(.*)$/mx)[0];
       } @{$sth->fetchall_arrayref()}];
 
       $sth->finish();
@@ -77,7 +76,7 @@ Bio::Das::ProServer::SourceHydra::dbi - A database-backed implementation of B::D
 
 =head1 VERSION
 
-$Revision: 2.52 $
+$Revision: 453 $
 
 =head1 AUTHOR
 
